@@ -1,6 +1,6 @@
 package Bundle::CVSMonitor;
 
-$VERSION = 1.04;
+$VERSION = 1.06;
 
 1;
 
@@ -20,7 +20,7 @@ Array::Window
 
 CGI
 
-CGI::Carp          - For it's fatalsToBrowser
+CGI::Carp          - For its fatalsToBrowser
 
 Chart::Math::Axis  - Calculate correct graph axis
 
@@ -32,6 +32,8 @@ Class::Default
 
 Class::Inspector   - Look at classes
 
+Class::Handle      - Look at classes
+
 Config::Tiny       - Config files
 
 Date::Format       - Used to generate RSS content
@@ -44,6 +46,8 @@ File::Flat         - Flat filesystem
 
 File::Temp
 
+File::Which
+
 FindBin
 
 GD::Graph          - Graphs
@@ -82,6 +86,6 @@ XML::Generator     - Used to generate RSS content
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>F<cvsmonitor@ali.as>E<gt>
+Adam Kennedy (Maintainer), L<http://ali.as/>, cvsmonitor@ali.as
 
 =cut
